@@ -10,8 +10,7 @@ from urllib.parse import urlparse
 from django.conf import settings
 from django.db import models
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
-
+from django.utils.translation import gettext_lazy as _
 from django_tools.models import UpdateInfoBaseModel, UpdateTimeBaseModel
 
 from for_runners.gpx_tools.humanize import human_distance, human_seconds
@@ -40,10 +39,16 @@ class LinkModelBase(UpdateTimeBaseModel):
 
     url = models.URLField(help_text=_("Link URL"))
     text = models.CharField(
-        max_length=127, help_text=_("Link text (leave empty to generate it from url)"), null=True, blank=True
+        max_length=127,
+        help_text=_("Link text (leave empty to generate it from url)"),
+        null=True,
+        blank=True,
     )
     title = models.CharField(
-        max_length=127, help_text=_("Link title (leave empty to generate it from url)"), null=True, blank=True
+        max_length=127,
+        help_text=_("Link title (leave empty to generate it from url)"),
+        null=True,
+        blank=True,
     )
 
     def get_text(self):
@@ -86,7 +91,9 @@ class EventModel(ModelAdminUrlMixin, UpdateInfoBaseModel):
         * lastupdateby
     """
 
-    no = models.PositiveIntegerField(help_text=_("Sequential number of the event"), null=True, blank=True)
+    no = models.PositiveIntegerField(
+        help_text=_("Sequential number of the event"), null=True, blank=True
+    )
     name = models.CharField(max_length=255, help_text=_("Name of the event"))
     start_date = models.DateField(help_text=_("Start date of the run"), null=True, blank=True)
     discipline = models.ForeignKey(DisciplineModel, on_delete=models.SET_NULL, null=True)
@@ -96,7 +103,7 @@ class EventModel(ModelAdminUrlMixin, UpdateInfoBaseModel):
         if self.no:
             parts.append("%i." % self.no)
         parts.append(self.name)
-        result = " ".join([part for part in parts if part])
+        result = " ".join(part for part in parts if part)
         return result
 
     def verbose_name(self):
@@ -105,7 +112,7 @@ class EventModel(ModelAdminUrlMixin, UpdateInfoBaseModel):
             year = self.start_date.strftime("%Y")
             if year not in self.name:
                 parts.append(year)
-        result = " ".join([part for part in parts if part])
+        result = " ".join(part for part in parts if part)
         return result
 
     verbose_name.short_description = _("Event Name")
@@ -157,11 +164,18 @@ class ParticipationModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
         decimal_places=4,
     )
     duration = models.TimeField(
-        verbose_name=_("Duration"), help_text=_("You officially measured finisher time"), null=True, blank=True
+        verbose_name=_("Duration"),
+        help_text=_("You officially measured finisher time"),
+        null=True,
+        blank=True,
+    )
+    start_number = models.CharField(
+        max_length=15, help_text=_("Your start number"), null=True, blank=True
     )
-    start_number = models.CharField(max_length=15, help_text=_("Your start number"), null=True, blank=True)
     finisher_count = models.PositiveIntegerField(
-        help_text=_("Number of participants who have finished in your discipline"), null=True, blank=True
+        help_text=_("Number of participants who have finished in your discipline"),
+        null=True,
+        blank=True,
     )
 
     def get_human_distance(self):
@@ -194,11 +208,17 @@ class ParticipationModel(ModelAdminUrlMixin, UpdateTimeBaseModel):
                 return pace * 60
 
     def verbose_name(self):
-        parts = [self.event.verbose_name(), "-", self.person.username, "-", self.get_human_distance()]
+        parts = [
+            self.event.verbose_name(),
+            "-",
+            self.person.username,
+            "-",
+            self.get_human_distance(),
+        ]
         if self.duration:
             parts.append(f"in {self.human_duration()}")
 
-        result = " ".join([part for part in parts if part])
+        result = " ".join(part for part in parts if part)
         return result
 
     verbose_name.short_description = _("Event Name")
@@ -220,7 +240,9 @@ class CostModel(UpdateTimeBaseModel):
      * lastupdatetime
     """
 
-    participation = models.ForeignKey(ParticipationModel, related_name="costs", on_delete=models.CASCADE)
+    participation = models.ForeignKey(
+        ParticipationModel, related_name="costs", on_delete=models.CASCADE
+    )
     name = models.CharField(max_length=15, help_text=_("The name of the item you dis pay for"))
     amount = models.DecimalField(
         help_text=_("How much did you pay for this?"),
